# -*- coding: utf-8 -*-
"""
app.admin.views
~~~~~~~~~~~~~~~

This module customizes the admin views.

:copyright: (c) 2017 European Spallation Source ERIC
:license: BSD 2-Clause, see LICENSE for more details.

"""
from wtforms import validators, fields
from flask_admin.contrib import sqla
from flask_admin.model.form import converts
from flask_login import current_user
from ..models import Item, User, Group, ICS_ID_RE


# Add custom model converter for CIText type
# See https://github.com/flask-admin/flask-admin/issues/1196
class AppAdminModelConverter(sqla.form.AdminModelConverter):

    @converts('CIText')
    def conv_CIText(self, field_args, **extra):
        return fields.TextAreaField(**field_args)


class AdminModelView(sqla.ModelView):
    model_form_converter = AppAdminModelConverter

    def is_accessible(self):
        return current_user.is_authenticated and current_user.is_admin


class GroupAdmin(AdminModelView):
    can_create = False
    can_edit = False
    can_delete = False

    def __init__(self, session):
        super().__init__(Group, session)


class UserAdmin(AdminModelView):
    can_create = False
    can_edit = False
    can_delete = False

    def __init__(self, session):
        super().__init__(User, session)


class ItemAdmin(AdminModelView):

    form_args = {
        'ics_id': {
            'label': 'ICS id',
            'validators': [validators.Regexp(ICS_ID_RE, message='ICS id shall match [A-Z]{3}[0-9]{3}')]
        }
    }

    def __init__(self, session):
        super().__init__(Item, session)
